@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod-core
-version: 1.4.20
-id: yesod-core-1.4.20-a64b314810952b5a1be9638e42c84862
-key: yesod_JOdpuak39YI63s06Griutp
+version: 1.4.20.2
+id: yesod-core-1.4.20.2-014d072d2152bbd04ae4cfe76f84438d
+key: yesod_9x5ixKSPBnb3BT17wR5G3v
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -30,35 +30,35 @@ hidden-modules: Yesod.Core.Internal.Session
                 Yesod.Routes.TH.Dispatch Yesod.Routes.TH.RenderRoute
                 Yesod.Routes.TH.ParseRoute Yesod.Routes.TH.RouteAttrs
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-core-1.4.20
-library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-core-1.4.20
-data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-core-1.4.20
-hs-libraries: HSyesod-core-1.4.20-JOdpuak39YI63s06Griutp
+import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-core-1.4.20.2
+library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-core-1.4.20.2
+data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-core-1.4.20.2
+hs-libraries: HSyesod-core-1.4.20.2-9x5ixKSPBnb3BT17wR5G3v
 depends:
-    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
-    auto-update-0.1.3-4edf36ce78b71bfaad1ce3737442c65f
+    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
+    auto-update-0.1.4-5802161b0d99b2a30d57c95848e07a31
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
-    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
-    blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
+    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
+    blaze-html-0.8.1.1-196db2ddcb827bc04473411dd00dd5eb
+    blaze-markup-0.7.0.3-301d79472dd24aabecf5f1be193f6bdb
     byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
+    case-insensitive-1.2.0.6-f940e4aded76d28f250fda2e1500b30b
     cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
-    clientsession-0.9.1.1-763bfd866302839ae7dcaa53517a3160
-    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
-    conduit-extra-1.1.12.1-34a75d65f1bcf0a6ace65de178beb2df
+    clientsession-0.9.1.1-460c757d370e23c2009b2fc0ceeee609
+    conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
+    conduit-extra-1.1.13.1-cf2e2742d7d01907ed25c65d155b9a5e
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    cookie-0.4.1.6-97fa5cf54d4ed1e2644dbcebe7255b51
-    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
+    cookie-0.4.2-28e8510d867302127f61174b072159ee
+    data-default-0.6.0-4c4f075845d560f7a31d444f67905db9
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
-    fast-logger-2.4.1-5b4c33804a079c795a3744fd9f8cdcd3
-    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
-    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
-    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-logger-0.3.18-77245c726e2e1fb18d9b7ba72ab04e41
+    fast-logger-2.4.6-432abdc0f5b043114ea69b7c4625cae5
+    http-types-0.9-abc209b9e91b870b477d7ec7669b4ae8
+    lifted-base-0.2.3.6-9c13caa8bbd360a88b87891885feeeff
+    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
+    monad-logger-0.3.18-1374b457a8b7165408364c0bd477c532
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     mwc-random-0.13.4.0-5fa3ad33ef5e7f15e9e572967b6dc242
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
@@ -66,10 +66,10 @@ depends:
     path-pieces-0.2.1-f62a4ee86afe2692f9fb79d2dd895499
     primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
-    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
+    resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
     safe-0.3.9-b613242f536083d5bb04920ede356aea
-    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
-    shakespeare-2.0.8-88acbcac23cb55d5f3c82ebba9b11159
+    semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
+    shakespeare-2.0.8.2-ff3f7104513a25f68869f5890fce9d82
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
@@ -78,10 +78,10 @@ depends:
     unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
-    wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
-    wai-extra-3.0.15-2f88b45989ced36024c3ff3943866d23
-    wai-logger-2.2.4.1-fb66803d5627851b4e6cf4f9505489de
-    warp-3.2.4-afffa286f2a73716d3c875d3f70e8c61
+    wai-3.2.1-82fcd8afd3d66bf63829f2c0f9ec2308
+    wai-extra-3.0.15.1-954bd1f4cbd0dadcc30817e6afe9d17a
+    wai-logger-2.2.7-be4dfe43e81d159502c14b31210da2fe
+    warp-3.2.6-747ccbb2aaea6b63942f452bd0d269ae
     word8-0.1.2-9a296ac80618be494d93f29b398e749d
 haddock-interfaces: /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
 haddock-html: /usr/share/doc/haskell-yesod-core/html
